Previously we had a knowledge base requirement for x-ipe, but at that time the needs were not very clear, but I know the demand is there. So please study the x-ipe project to discover the potential requirements and the ui and ux to best integrate and utilize the knowledge base function to existing x-ipe functions.

the already discovered needs:
1. for x-ipe it's good at delivering new application from scratch, but there are lots of legacy application to maintain or build new feature on top of existing code that base on existing requirement documents or user manuals. So we may need a centralized space to store the project or application related docs for reference in any phases in project delivery.
2. for some project or application, maybe some designs references required such as  on market application feature research, technical design reference, or some any other type of reference. we can have this centralized space as 'input' or 'memory' to learn from it or to dump the knowledge research persist them into the knowledge base.

